@@ -4,7 +4,7 @@ from fabric.api import local
 from .utils import local_template, prepare_folder
 
 def get_custom_file(type_, name, template, target_path=None, target_extension=None,
-                target_is_executable=None, target_filename=None, options=None):
+                target_is_executable=None, target_filename=None, maiden_name=None, options=None):
     """ factory for CustomFiles """
     if type_ == 'nginx':
         return NGINXCustomFile(name, template, options=options)
@@ -19,7 +19,7 @@ def get_custom_file(type_, name, template, target_path=None, target_extension=No
     elif type_ == "newrelic_config":
         return NewrelicConfigCustomFile(name, template, options=options)
     elif type_ == "custom":
-        return CustomFile(name, template, target_path, target_extension, target_is_executable, target_filename, options)
+        return CustomFile(name, template, target_path, target_extension, target_is_executable, target_filename, maiden_name, options)
     else:
         raise NotImplementedError
 
@@ -28,10 +28,12 @@ class CustomFile(object):
     is_executable = False
     relative_path = ""
     extension = ""
+    maiden_name = None
 
     def __init__(self, name, template=None, target_path=None, target_extension=None,
-                target_is_executable=None, target_filename=None, options=None):
+                target_is_executable=None, target_filename=None, maiden_name=None, options=None):
         self.name = name
+        self.maiden_name = maiden_name
         self.template = template
 
         if target_is_executable:
@@ -48,6 +50,12 @@ class CustomFile(object):
 
         self.options = options if options else {}
 
+    @property
+    def unsuffixed_name(self):
+        if self.maiden_name is not None:
+            return self.maiden_name
+        return self.name
+
     def build(self, base_path, options=None, extra_template_dir=None):
         print "{%s}: building file %s" % (self.__class__.__name__, self.name)
 
